==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/NextQuarterExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WrapperExpressionDescriptionMetadata } from "./WrapperExpressionDescriptionMetadata";
import { NextQuarterExpressionDescription } from "./NextQuarterExpressionDescription";
/**
 * @hidden
 */
export let NextQuarterExpressionDescriptionMetadata = /*@__PURE__*/ (() => {
    class NextQuarterExpressionDescriptionMetadata extends Base {
        static b(a) {
            if (NextQuarterExpressionDescriptionMetadata.a == null) {
                NextQuarterExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                NextQuarterExpressionDescriptionMetadata.c(NextQuarterExpressionDescriptionMetadata.a);
            }
            if (a.k(NextQuarterExpressionDescriptionMetadata.a)) {
                return;
            }
            a.ab(NextQuarterExpressionDescriptionMetadata.a);
        }
        static c(a) {
            WrapperExpressionDescriptionMetadata.c(a);
        }
        static d(a) {
            NextQuarterExpressionDescriptionMetadata.b(a);
            a.ad("NextQuarterExpression", () => new NextQuarterExpressionDescription());
            a.ac("NextQuarterExpression", NextQuarterExpressionDescriptionMetadata.a);
        }
    }
    NextQuarterExpressionDescriptionMetadata.$t = markType(NextQuarterExpressionDescriptionMetadata, 'NextQuarterExpressionDescriptionMetadata');
    NextQuarterExpressionDescriptionMetadata.a = null;
    return NextQuarterExpressionDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/NextQuarterExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WrapperExpressionDescriptionMetadata } from "./WrapperExpressionDescriptionMetadata";
import { NextQuarterExpressionDescription } from "./NextQuarterExpressionDescription";
/**
 * @hidden
 */
export let NextQuarterExpressionDescriptionMetadata = /*@__PURE__*/ (() => {
    class NextQuarterExpressionDescriptionMetadata extends Base {
        static b(a) {
            if (NextQuarterExpressionDescriptionMetadata.a == null) {
                NextQuarterExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                NextQuarterExpressionDescriptionMetadata.c(NextQuarterExpressionDescriptionMetadata.a);
            }
            if (a.k(NextQuarterExpressionDescriptionMetadata.a)) {
                return;
            }
            a.ac(NextQuarterExpressionDescriptionMetadata.a);
        }
        static c(a) {
            WrapperExpressionDescriptionMetadata.c(a);
        }
        static d(a) {
            NextQuarterExpressionDescriptionMetadata.b(a);
            a.ae("NextQuarterExpression", () => new NextQuarterExpressionDescription());
            a.ad("NextQuarterExpression", NextQuarterExpressionDescriptionMetadata.a);
        }
    }
    NextQuarterExpressionDescriptionMetadata.$t = markType(NextQuarterExpressionDescriptionMetadata, 'NextQuarterExpressionDescriptionMetadata');
    NextQuarterExpressionDescriptionMetadata.a = null;
    return NextQuarterExpressionDescriptionMetadata;
})();
